<?php

namespace Modules\Cotacao\Modules\Pedido\Services;

use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class Sup95000AprovacaoPedidosColetaInternetService
{
    protected $connection;
    
    public function __construct($conection)
    {
        $this->connection = $conection;
    }
    
    public function beginTransaction()
    {
        $this->connection->beginTransaction();
    }
    
    public function commit()
    {
        $this->connection->commit();
    }
    
    public function rollback()
    {
        $this->connection->rollback();
    }
    
    public function gerarCotacaoPrecos($pedido)
    {
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'GRAVA_COTWEB');
    
        $procedure->addParam(new Param('P_CDFILIAL',        Param::PARAM_INPUT, $pedido['CDFILIAL'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRPEDCOLETA',     Param::PARAM_INPUT, $pedido['NRPEDCOLETA'],     Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREGIAO',        Param::PARAM_INPUT, $pedido['CDREGIAO'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFORNECED',      Param::PARAM_INPUT, $pedido['CDFORNECED'],      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEMINI',        Param::PARAM_INPUT, $pedido['NRSEMINI'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEMFIN',        Param::PARAM_INPUT, $pedido['NRSEMFIN'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ENTRALISTA',      Param::PARAM_INPUT, $pedido['ENTRALISTA'],      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_COTA_N_GER',      Param::PARAM_OUTPUT, null,                      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERINCL',      Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        
        return $procedure->execute();
    }
    
    public function procAceitaPedcotweb($cdfilial, $nrpedidocol, $idconsiste)
    {
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'ACEITA_PEDCOTWEB');
        
        $procedure->addParam(new Param('P_CDFILIAL',    Param::PARAM_INPUT, $cdfilial,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRPEDIDOCOL', Param::PARAM_INPUT, $nrpedidocol, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDCONSISTE',  Param::PARAM_INPUT, $idconsiste,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDACEITEOK',  Param::PARAM_OUTPUT, null,        Param::PARAM_TYPE_STR, 200));
        
        return $procedure->execute();
    }
    
    public function retornaTermoAceite($cdforneced)
    {
        $query = "SELECT IDUTLCTRLTERMO FROM FORNECEDOR WHERE CDFORNECED = :CDFORNECED";

        $params = [
            "CDFORNECED" => $cdforneced
        ];

        $std = $this->connection->prepare($query);
        $std->execute($params);
        
        $termoAceite = $std->fetchAll();
        
        if (isset($termoAceite[0]['IDUTLCTRLTERMO'])) {
            return $termoAceite[0]['IDUTLCTRLTERMO'];
        } 
        
        return 'N';
    }
    
    public function verificaPedidoColetaGerado($pedido)
    {
        $query = "SELECT '1' FROM ITEMCOLE I WHERE I.CDFILIAL= :P_CDFILIAL AND INSTR( :P_NRPEDIDOCOL, I.NRPEDIDOCOL ) <> 0 AND (INSTR( :P_CDREGIAO, I.CDREGIAO ) <> 0 OR :P_CDREGIAO = 'T') AND INSTR( :P_CDFORNECED, I.CDFORNECED ) <> 0";
        
        $params = array(
            "P_CDFILIAL"    => $pedido["CDFILIAL"],
            "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"],
            "P_CDREGIAO"    => $pedido["CDREGIAO"],
            "P_CDFORNECED"  => $pedido["CDFORNECED"]
        );
        
        $std = $this->connection->prepare($query);
        $std->execute($params);
        
        $pedidoColeta = $std->fetchAll();
        
        if (count($pedidoColeta)) {
            return true;
        }
        
        return false;
    }
    
}
