<?php

namespace Geral\Logic\ParametrosEstoque;

use Estoque\Entities\Diainvefili;
use Geral\Entities\Almoxarifado;
use Geral\Entities\Localestoque;
use Geral\Entities\Paramestoque;
use Geral\Entities\Paramfilial;
use Geral\Util\Ambiente;
use Geral\Util\DateUtil;
use Geral\Util\TratamentoDeMensagens;
use Setforms2\Runtime\Helper\Procedure;
use Setforms2\Runtime\Helper\Procedure\Param;

/**
 * Created by PhpStorm.
 * User: victornovy
 * Date: 28/10/2014
 * Time: 13:45
 */

class ParametrosEstoque {

    // Formata a data de forma que possa ser inserida no banco
    public static function formataData($data)
    {
        if (strlen($data) == 19)
            $data = DateUtil::truncateString($data);
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }

    public static function callProcedureAtualizaAlmoxarifadoPdr($filial, $almoxarifado)
    {
        try {
            $connection = \Setforms2\Shared\Registry::getEntityManager();
            $connection->beginTransaction();
            $procedure = new Procedure('ATUALIZA_ALMOXARIFADO_PDR');
            $procedure->addParam(
                new Param(
                    'P_CDFILIAL',
                    Param::PARAM_INPUT,
                    $filial,
                    Param::PARAM_TYPE_STR
                )
            );
            $procedure->addParam(
                new Param(
                    'P_CDALMOXARIFE',
                    Param::PARAM_INPUT,
                    $almoxarifado,
                    Param::PARAM_TYPE_STR
                )
            );
            $procedure->call();
            $connection->flush();
            $connection->commit();
            \SetForms2\Shared\Registry::getEntityManager()->flush();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function insertAlmoxarifadoLocalizacao($filial, $almox, $descAlmox, $local, $descLocal, $organizacao)
    {
        $validaAlmox = Almoxarifado::findOneByCdfilialAndCdalmoxarifeAndNrorg($filial, $almox, $organizacao);
        if (!$validaAlmox) {
            self::insertAlmoxarifado($filial, $almox, $descAlmox, $organizacao);
            self::insertLocalizacao($filial, $almox, $local, $descLocal, $organizacao);
        } else {
            $validaLocal = Localestoque::findOneByCdfilialAndCdalmoxarifeAndCdlocalestoqAndNrorg(
                $filial, $almox, $local, $organizacao
            );
            if (!$validaLocal) {
                self::insertLocalizacao($filial, $almox, $local, $descLocal, $organizacao);
            }
        }
    }

    public static function insertAlmoxarifado($filial, $almox, $descAlmox, $organizacao)
    {
        try {
            $connection = \Setforms2\Shared\Registry::getEntityManager();
            $connection->beginTransaction();
            /** @var Almoxarifado $validaAlmox */
            $novoAlmox = new Almoxarifado();
            $novoAlmox->setCdfilial($filial);
            $novoAlmox->setCdalmoxarife($almox);
            $novoAlmox->setDsalmoxarife($descAlmox);
            $novoAlmox->setNrorg($organizacao);
            $novoAlmox->setNrorginclusao($organizacao);
            $novoAlmox->setNrorgultatu($organizacao);
            $novoAlmox->setDtinclusao(self::formataData(now()));
            $novoAlmox->setDtultatu(self::formataData(now()));
            $novoAlmox->setCdoperinclusao(Ambiente::getCdOperador());
            $novoAlmox->setCdoperultatu(Ambiente::getCdOperador());
            $novoAlmox->persist();
            \Setforms2\Shared\Registry::getEntityManager()->flush();
            $connection->flush();
            $connection->commit();
        } catch (\Exception $e) {
            TratamentoDeMensagens::exibirMensagens($e, true);
        }
    }

    public static function insertLocalizacao($filial, $almox, $local, $descLocal, $organizacao)
    {
        try {
            $connection = \Setforms2\Shared\Registry::getEntityManager();
            $connection->beginTransaction();
            /** @var  Localestoque $novoLocal */
            $novoLocal = new Localestoque();
            $novoLocal->setCdfilial($filial);
            $novoLocal->setCdalmoxarife($almox);
            $novoLocal->setCdlocalestoq($local);
            $novoLocal->setDslocalestoq($descLocal);
            $novoLocal->setIddispconped('S');
            $novoLocal->setNrorg($organizacao);
            $novoLocal->setNrorginclusao($organizacao);
            $novoLocal->setNrorgultatu($organizacao);
            $novoLocal->setDtinclusao(self::formataData(now()));
            $novoLocal->setDtultatu(self::formataData(now()));
            $novoLocal->setCdoperinclusao(Ambiente::getCdOperador());
            $novoLocal->setCdoperultatu(Ambiente::getCdOperador());
            $novoLocal->persist();
            \Setforms2\Shared\Registry::getEntityManager()->flush();
            $connection->flush();
            $connection->commit();
        } catch (\Exception $e) {
            TratamentoDeMensagens::exibirMensagens($e, true);
        }
    }

    public static function apagaDiaInventario($filial, $organizacao)
    {
        try {
            /** @var Diainvefili $dia */
            $diainvefili = Diainvefili::findByCdfilialAndNrorg($filial, $organizacao);
            foreach ($diainvefili as $dia) {
                $connection = \Setforms2\Shared\Registry::getEntityManager();
                $connection->beginTransaction();
                $dia->delete();
                \Setforms2\Shared\Registry::getEntityManager()->flush();
                $connection->flush();
                $connection->commit();
            }
        } catch (\Exception $e) {
            TratamentoDeMensagens::exibirMensagens($e, true);
        }
    }

    public static function updateParamfilial(
        $filial, $controlaEstoque, $atualizaOnLine, $emiteMensagem, $messesFechados, $dia,
        $produtosComposicao, $retiradaAjuste, $codigoBarra, $saidaProdutoInativo, $estoqueComplementar,
        $tipoCusto, $implantacaoEstoque, $ajusteInventario, $organizacao

    )
    {
        try {
            /** @var Paramfilial $paramFilial */
            $connection = \Setforms2\Shared\Registry::getEntityManager();
            $connection->beginTransaction();
            $paramFilial = Paramfilial::findOneByCdfilialAndNrorg($filial, $organizacao);
            $paramFilial->setIdctrlestq($controlaEstoque);
            $paramFilial->setIdestonline($atualizaOnLine);
            $paramFilial->setIdmensestneg($emiteMensagem);
            $paramFilial->setIdblqestfmes($messesFechados);
            $paramFilial->setNrdiabloqest($dia);
            $paramFilial->setIdblprcomest($produtosComposicao);
            $paramFilial->setIdgeraretaju($retiradaAjuste);
            $paramFilial->setIdutcodbarfi($codigoBarra);
            $paramFilial->setIdperproinat($saidaProdutoInativo);
            $paramFilial->setIdreqcompest($estoqueComplementar);
            $paramFilial->setCdtipcustest($tipoCusto);
            $paramFilial->setIdordimplant($implantacaoEstoque);
            $paramFilial->setIdordajuinve($ajusteInventario);
            $paramFilial->persist();
            \Setforms2\Shared\Registry::getEntityManager()->flush();
            $connection->flush();
            $connection->commit();
        } catch (\Exception $e) {
            TratamentoDeMensagens::exibirMensagens($e, true);
        }
    }

    public static function insertParamestoque($organizacao)
    {
        try {
            /** @var Paramestoque $paramEstoque */
            $connection = \Setforms2\Shared\Registry::getEntityManager();
            $connection->beginTransaction();
            $paramEstoque = new Paramestoque();
            $paramEstoque->setCdparestoq('1');
            $paramEstoque->setIdtratavenc('A');
            $paramEstoque->setVrpetoleentr('10');
            $paramEstoque->setIdconsfornfj('S');
            $paramEstoque->setIdbloqforirr('N');
            $paramEstoque->setIdlancdtmen('S');
            $paramEstoque->setNrdiasentr('30');
            $paramEstoque->setNrdiassaid('30');
            $paramEstoque->setNrdiasajus('30');
            $paramEstoque->setIdlancdtmai('N');
            $paramEstoque->setIdconautirrg('S');
            $paramEstoque->setIdbloqpresto('N');
            $paramEstoque->setIdaltdtfecdia('N');
            $paramEstoque->setIdgtgtxtfdia('S');
            $paramEstoque->setIdctrlestnvprod('E');
            $paramEstoque->setIdativo('S');
            $paramEstoque->setNrorg($organizacao);
            $paramEstoque->setNrorginclusao($organizacao);
            $paramEstoque->setNrorgultatu($organizacao);
            $paramEstoque->setCdoperinclusao(Ambiente::getCdOperador());
            $paramEstoque->setCdoperultatu(Ambiente::getCdOperador());
            $paramEstoque->setDtinclusao(self::formataData(now()));
            $paramEstoque->setDtultatu(self::formataData(now()));
            $paramEstoque->persist();
            \Setforms2\Shared\Registry::getEntityManager()->flush();
            $connection->flush();
            $connection->commit();
        } catch (\Exception $e) {
            TratamentoDeMensagens::exibirMensagens($e, true);
        }
    }
}